ferneyhough
===========

.. automodule:: abjad.demos.ferneyhough

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.demos.ferneyhough.configure_lilypond_file.configure_lilypond_file
      ~abjad.demos.ferneyhough.configure_score.configure_score
      ~abjad.demos.ferneyhough.make_lilypond_file.make_lilypond_file
      ~abjad.demos.ferneyhough.make_nested_tuplet.make_nested_tuplet
      ~abjad.demos.ferneyhough.make_row_of_nested_tuplets.make_row_of_nested_tuplets
      ~abjad.demos.ferneyhough.make_rows_of_nested_tuplets.make_rows_of_nested_tuplets
      ~abjad.demos.ferneyhough.make_score.make_score
